@@ -29,6 +29,7 @@ Copyright_License {
 #include "Language/Language.hpp"
 #include "Util/CharUtil.hpp"
 #include "Util/StringUtil.hpp"
+#include "Util/NumberParser.hpp"
 #include "Util/Macros.hpp"
 #include "Geo/Math.hpp"
 #include "IO/LineReader.hpp"
@@ -163,8 +164,11 @@ struct TempAirspaceType
   void
   AddPolygon(Airspaces &airspace_database)
   {
+    if (points.size() < 3)
+      return;
+
     AbstractAirspace *as = new AirspacePolygon(points);
-    as->SetProperties(name, type, base, top);
+    as->SetProperties(std::move(name), type, base, top);
     as->SetRadio(radio);
     as->SetDays(days_of_operation);
     airspace_database.Add(as);
@@ -174,7 +178,7 @@ struct TempAirspaceType
   AddCircle(Airspaces &airspace_database)
   {
     AbstractAirspace *as = new AirspaceCircle(center, radius);
-    as->SetProperties(name, type, base, top);
+    as->SetProperties(std::move(name), type, base, top);
     as->SetRadio(radio);
     as->SetDays(days_of_operation);
     airspace_database.Add(as);
@@ -285,7 +289,7 @@ ReadAltitude(const TCHAR *buffer, AirspaceAltitude &altitude)
 
     if (IsDigitASCII(*p)) {
       TCHAR *endptr;
-      value = fixed(_tcstod(p, &endptr));
+      value = fixed(ParseDouble(p, &endptr));
       p = endptr;
     } else if (StringIsEqualIgnoreCase(p, _T("GND"), 3) ||
                StringIsEqualIgnoreCase(p, _T("AGL"), 3)) {
@@ -374,14 +378,14 @@ ReadCoords(const TCHAR *buffer, GeoPoint &point)
 
   // ToDo, add more error checking and making it more tolerant/robust
 
-  double deg = _tcstod(buffer, &endptr);
+  double deg = ParseDouble(buffer, &endptr);
   if ((buffer == endptr) || (*endptr == '\0'))
     return false;
 
   if (*endptr == ':') {
     endptr++;
 
-    double min = _tcstod(endptr, &endptr);
+    double min = ParseDouble(endptr, &endptr);
     if (*endptr == '\0')
       return false;
 
@@ -390,7 +394,7 @@ ReadCoords(const TCHAR *buffer, GeoPoint &point)
     if (*endptr == ':') {
       endptr++;
 
-      double sec = _tcstod(endptr, &endptr);
+      double sec = ParseDouble(endptr, &endptr);
       if (*endptr == '\0')
         return false;
 
@@ -413,14 +417,14 @@ ReadCoords(const TCHAR *buffer, GeoPoint &point)
   if (*endptr == '\0')
     return false;
 
-  deg = _tcstod(endptr, &endptr);
+  deg = ParseDouble(endptr, &endptr);
   if ((buffer == endptr) || (*endptr == '\0'))
     return false;
 
   if (*endptr == ':') {
     endptr++;
 
-    double min = _tcstod(endptr, &endptr);
+    double min = ParseDouble(endptr, &endptr);
     if (*endptr == '\0')
       return false;
 
@@ -429,7 +433,7 @@ ReadCoords(const TCHAR *buffer, GeoPoint &point)
     if (*endptr == ':') {
       endptr++;
 
-      double sec = _tcstod(endptr, &endptr);
+      double sec = ParseDouble(endptr, &endptr);
       if (*endptr == '\0')
         return false;
 
@@ -452,14 +456,21 @@ ReadCoords(const TCHAR *buffer, GeoPoint &point)
   return true;
 }
 
+static Angle
+ParseBearingDegrees(const TCHAR *p, TCHAR **endptr=nullptr)
+{
+  return Angle::Degrees(ParseDouble(p, endptr)).AsBearing();
+}
+
 static void
 ParseArcBearings(const TCHAR *buffer, TempAirspaceType &temp_area)
 {
   // Determine radius and start/end bearing
   TCHAR *endptr;
-  temp_area.radius = Units::ToSysUnit(fixed(_tcstod(&buffer[2], &endptr)), Unit::NAUTICAL_MILES);
-  Angle start_bearing = Angle::Degrees(_tcstod(&endptr[1], &endptr)).AsBearing();
-  Angle end_bearing = Angle::Degrees(_tcstod(&endptr[1], &endptr)).AsBearing();
+  temp_area.radius = Units::ToSysUnit(fixed(ParseDouble(&buffer[2], &endptr)),
+                                      Unit::NAUTICAL_MILES);
+  Angle start_bearing = ParseBearingDegrees(&endptr[1], &endptr);
+  Angle end_bearing = ParseBearingDegrees(&endptr[1], &endptr);
 
   temp_area.AppendArc(start_bearing, end_bearing);
 }
@@ -561,7 +572,7 @@ ParseLine(Airspaces &airspace_database, TCHAR *line,
 
     case _T('C'):
     case _T('c'):
-      temp_area.radius = Units::ToSysUnit(fixed(_tcstod(&line[2], nullptr)),
+      temp_area.radius = Units::ToSysUnit(fixed(ParseDouble(&line[2])),
                                           Unit::NAUTICAL_MILES);
       temp_area.AddCircle(airspace_database);
       temp_area.Reset();
@@ -603,9 +614,7 @@ ParseLine(Airspaces &airspace_database, TCHAR *line,
       if (value == nullptr)
         break;
 
-      if (!temp_area.points.empty())
-        temp_area.AddPolygon(airspace_database);
-
+      temp_area.AddPolygon(airspace_database);
       temp_area.Reset();
 
       temp_area.type = ParseType(value);
@@ -765,7 +774,7 @@ ParseCircleTNP(const TCHAR *buffer, TempAirspaceType &temp_area)
   const TCHAR* parameter;
   if ((parameter = StringAfterPrefixCI(buffer, _T("RADIUS="))) == nullptr)
     return false;
-  temp_area.radius = Units::ToSysUnit(fixed(_tcstod(parameter, nullptr)),
+  temp_area.radius = Units::ToSysUnit(fixed(ParseDouble(parameter)),
                                       Unit::NAUTICAL_MILES);
 
   if ((parameter = _tcsstr(parameter, _T(" "))) == nullptr)
@@ -788,9 +797,9 @@ ParseLineTNP(Airspaces &airspace_database, TCHAR *line,
 
   const TCHAR* parameter;
   if ((parameter = StringAfterPrefixCI(line, _T("INCLUDE="))) != nullptr) {
-    if (StringIsEqualIgnoreCase(parameter, _T("YES")))
+    if (StringStartsWithIgnoreCase(parameter, _T("YES")))
       ignore = false;
-    else if (StringIsEqualIgnoreCase(parameter, _T("NO")))
+    else if (StringStartsWithIgnoreCase(parameter, _T("NO")))
       ignore = true;
 
     return true;
@@ -823,16 +832,12 @@ ParseLineTNP(Airspaces &airspace_database, TCHAR *line,
     if (!ParseArcTNP(parameter, temp_area))
       return false;
   } else if ((parameter = StringAfterPrefixCI(line, _T("TITLE="))) != nullptr) {
-    if (!temp_area.points.empty())
-      temp_area.AddPolygon(airspace_database);
-
+    temp_area.AddPolygon(airspace_database);
     temp_area.ResetTNP();
 
     temp_area.name = parameter;
   } else if ((parameter = StringAfterPrefixCI(line, _T("TYPE="))) != nullptr) {
-    if (!temp_area.points.empty())
-      temp_area.AddPolygon(airspace_database);
-
+    temp_area.AddPolygon(airspace_database);
     temp_area.ResetTNP();
 
     temp_area.type = ParseTypeTNP(parameter);
@@ -920,8 +925,7 @@ AirspaceParser::Parse(TLineReader &reader, OperationEnvironment &operation)
   }
 
   // Process final area (if any)
-  if (!temp_area.points.empty())
-    temp_area.AddPolygon(airspaces);
+  temp_area.AddPolygon(airspaces);
 
   return true;
 }
