@@ -21,9 +21,9 @@ Copyright_License {
 }
 */
 
-#include "Device/Driver/LX/Internal.hpp"
+#include "Internal.hpp"
 #include "Device/Port/Port.hpp"
-#include "Device/Internal.hpp"
+#include "Device/Util/NMEAWriter.hpp"
 #include "LX1600.hpp"
 #include "V7.hpp"
 
