@@ -22,7 +22,6 @@
 #ifndef AIRSPACE_WARNING_MANAGER_HPP
 #define AIRSPACE_WARNING_MANAGER_HPP
 
-#include "Util/NonCopyable.hpp"
 #include "AirspaceWarning.hpp"
 #include "AirspaceWarningConfig.hpp"
 #include "Util/AircraftStateFilter.hpp"
@@ -47,9 +46,7 @@ class AirspaceAircraftPerformance;
  * - Task (longer range predicted warning based on current leg of task)
  *
  */
-class AirspaceWarningManager: 
-  public NonCopyable
-{
+class AirspaceWarningManager {
   AirspaceWarningConfig config;
 
   const Airspaces &airspaces;
@@ -81,6 +78,8 @@ public:
    */
   AirspaceWarningManager(const Airspaces &_airspaces);
 
+  AirspaceWarningManager(const AirspaceWarningManager &) = delete;
+
   gcc_pure
   const TaskProjection &GetProjection() const;
 
@@ -149,7 +148,7 @@ public:
    *
    * @param airspace Airspace to find warning for
    *
-   * @return Pointer to airspace warning item (or NULL if not found)
+   * @return Pointer to airspace warning item (or nullptr if not found)
    */
   AirspaceWarning* GetWarningPtr(const AbstractAirspace& airspace);
 
@@ -158,7 +157,7 @@ public:
    *
    * @param airspace Airspace for which to create warning for
    *
-   * @return Pointer to airspace warning item (or NULL if not found)
+   * @return Pointer to airspace warning item (or nullptr if not found)
    */
   AirspaceWarning* GetNewWarningPtr(const AbstractAirspace& airspace);
 
