@@ -27,7 +27,7 @@ Copyright_License {
 #include "Screen/Point.hpp"
 #include "Projection.hpp"
 #include "Geo/GeoBounds.hpp"
-#include "Util/DebugFlag.hpp"
+#include "Math/Point2D.hpp"
 
 #include <algorithm>
 
@@ -36,9 +36,11 @@ Copyright_License {
 class WindowProjection:
   public Projection
 {
-  DebugFlag screen_size_initialised;
+#ifndef NDEBUG
+  bool screen_size_initialised;
+#endif
 
-  unsigned screen_width, screen_height;
+  Point2D<unsigned> screen_size;
 
   /**
    * Geographical representation of the screen boundaries.
@@ -46,9 +48,13 @@ class WindowProjection:
    * This is a cached member that has to be updated manually by
    * calling UpdateScreenBounds()
    */
-  GeoBounds screenbounds_latlon;
+  GeoBounds screen_bounds;
 
 public:
+#ifndef NDEBUG
+  WindowProjection():screen_size_initialised(false) {}
+#endif
+
   /**
    * Converts a geographical location to a screen coordinate if the
    * location is within the visible bounds
@@ -78,9 +84,12 @@ public:
     assert(new_size.cx > 0);
     assert(new_size.cy > 0);
 
-    screen_width = new_size.cx;
-    screen_height = new_size.cy;
+    screen_size.x = new_size.cx;
+    screen_size.y = new_size.cy;
+
+#ifndef NDEBUG
     screen_size_initialised = true;
+#endif
   }
 
   void SetMapRect(const PixelRect &rc) {
@@ -103,7 +112,7 @@ public:
   unsigned GetScreenWidth() const {
     assert(screen_size_initialised);
 
-    return screen_width;
+    return screen_size.x;
   }
 
   /**
@@ -113,7 +122,7 @@ public:
   unsigned GetScreenHeight() const {
     assert(screen_size_initialised);
 
-    return screen_height;
+    return screen_size.y;
   }
 
   /**
@@ -162,10 +171,10 @@ public:
   // used by terrain renderer, topography and airspace
   gcc_pure
   const GeoBounds &GetScreenBounds() const {
-    return screenbounds_latlon;
+    return screen_bounds;
   }
 
-  /** Updates the cached screenbounds_latlon member */
+  /** Updates the cached screen_bounds member */
   void UpdateScreenBounds();
 
 protected:
