@@ -27,20 +27,23 @@ Copyright_License {
 
 #include "shapelib/mapserver.h"
 #include "Geo/GeoBounds.hpp"
-#include "Util/NonCopyable.hpp"
 #include "Util/AllocatedArray.hpp"
 #include "Util/Serial.hpp"
 #include "Math/fixed.hpp"
 #include "Screen/Color.hpp"
 #include "ResourceId.hpp"
 
+#ifdef ENABLE_OPENGL
+#include "XShapePoint.hpp"
+#endif
+
 #include <assert.h>
 
 class WindowProjection;
 class XShape;
 struct zzip_dir;
 
-class TopographyFile : private NonCopyable {
+class TopographyFile {
   struct ShapeList {
     const ShapeList *next;
 
@@ -55,39 +58,44 @@ class TopographyFile : private NonCopyable {
    */
   Serial serial;
 
-  struct zzip_dir *dir;
+  zzip_dir *const dir;
 
   shapefileObj file;
 
+  /**
+   * The center of shapefileObj::bounds.
+   */
+  GeoPoint center;
+
   AllocatedArray<ShapeList> shapes;
   const ShapeList *first;
 
-  int label_field;
+  const int label_field;
 
-  ResourceId icon, big_icon;
+  const ResourceId icon, big_icon;
 
-  unsigned pen_width;
+  const unsigned pen_width;
 
-  Color color;
+  const Color color;
 
   /**
    * The threshold value for the visibility check. If the current scale
    * is below this value the contents of this TopographyFile will be drawn.
    */
-  fixed scale_threshold;
+  const fixed scale_threshold;
 
   /**
    * The threshold value for label rendering. If the current scale
    * is below this value no labels of this TopographyFile will be drawn.
    */
-  fixed label_threshold;
+  const fixed label_threshold;
 
   /**
    * The threshold value for label rendering in important style . If the current
    * scale is below this value labels of this TopographyFile will be drawn
    * in standard style
    */
-  fixed important_label_threshold;
+  const fixed important_label_threshold;
 
   /**
    * The current scope of the shape cache.  If the screen exceeds this
@@ -105,21 +113,21 @@ public:
 
   public:
     const_iterator &operator++() {
-      assert(current != NULL);
+      assert(current != nullptr);
 
       current = current->next;
       return *this;
     }
 
     const XShape &operator*() const {
-      assert(current != NULL);
-      assert(current->shape != NULL);
+      assert(current != nullptr);
+      assert(current->shape != nullptr);
 
       return *current->shape;
     }
 
     const XShape *operator->() const {
-      assert(current != NULL);
+      assert(current != nullptr);
 
       return current->shape;
     }
@@ -148,7 +156,7 @@ public:
    * be rendered in default style
    * @return
    */
-  TopographyFile(struct zzip_dir *dir, const char *shpname,
+  TopographyFile(zzip_dir *dir, const char *shpname,
                  fixed threshold, fixed label_threshold,
                  fixed important_label_threshold,
                  const Color color,
@@ -157,6 +165,8 @@ public:
                  ResourceId big_icon=ResourceId::Null(),
                  unsigned pen_width=1);
 
+  TopographyFile(const TopographyFile &) = delete;
+
   /**
    * The destructor clears the cache and closes the shapefile
    */
@@ -166,6 +176,10 @@ public:
     return serial;
   }
 
+  const GeoPoint &GetCenter() const {
+    return center;
+  }
+
   bool IsEmpty() const {
     return shapes.empty();
   }
@@ -203,13 +217,19 @@ public:
   }
 
   const_iterator end() const {
-    return const_iterator(NULL);
+    return const_iterator(nullptr);
   }
 
   gcc_pure
   unsigned GetSkipSteps(fixed map_scale) const;
 
 #ifdef ENABLE_OPENGL
+  gcc_pure
+  GeoPoint ToGeoPoint(const ShapePoint &p) const {
+    return GeoPoint(center.longitude + Angle::Native(fixed(p.x)),
+                    center.latitude + Angle::Native(fixed(p.y)));
+  }
+
   /**
    * @return thinning level, range: 0 .. XShape::THINNING_LEVELS-1
    */
