@@ -90,7 +90,7 @@ TestOpenAir()
   ok1(airspaces.GetSize() == 23);
 
   for (auto it = airspaces.begin(); it != airspaces.end(); ++it) {
-    const AbstractAirspace &airspace = *it->GetAirspace();
+    const AbstractAirspace &airspace = it->GetAirspace();
     if (_tcscmp(_T("Circle-Test"), airspace.GetName()) == 0) {
       if (!ok1(airspace.GetShape() == AbstractAirspace::Shape::CIRCLE))
         continue;
@@ -197,7 +197,7 @@ TestTNP()
   ok1(airspaces.GetSize() == 24);
 
   for (auto it = airspaces.begin(); it != airspaces.end(); ++it) {
-    const AbstractAirspace &airspace = *it->GetAirspace();
+    const AbstractAirspace &airspace = it->GetAirspace();
     if (_tcscmp(_T("Circle-Test"), airspace.GetName()) == 0) {
       if (!ok1(airspace.GetShape() == AbstractAirspace::Shape::CIRCLE))
         continue;
